@@ -44,9 +44,11 @@ def validator_metaclass(base=type):
         base.__name__ + "WithValidatorMeta",
         (base, ),
         {'__new__': lambda mcls, name, bases, namespace: base.__new__(mcls, name, bases, {
-            name: validated_method('validate_'+name[6:], func)
-                  if callable(func) and name.startswith('visit_')
-                  else func
+            name: (
+                validated_method('validate_'+name[6:], func)
+                if callable(func) and name.startswith('visit_')
+                else func
+            )
             for name, func in namespace.items()
         })}
     )
@@ -112,7 +114,7 @@ class BaseVisitor(with_metaclass(validator_metaclass(base=ABCMeta))):
                 if opt not in acceptable_options:
                     raise InvalidQuery(
                         "Invalid query part %r. Unsupported regex option %r. Only %s are supported !" % (
-                            value, opt, ', '.join(acceptable_options)
+                            options, opt, ', '.join(acceptable_options)
                         )
                     )
                 raw_options |= getattr(re, opt.upper())
